@@ -6,11 +6,10 @@
  * the configuration file.
  *
  *
- * SNARE GUI Version 2.3 Dated 1 March 2004
+ * SNARE GUI Version 2.4
  *
  ************************************************************/
 
-void update_objective_window(gchar *,gchar *,gchar *,gchar *,gchar *,gchar *,gchar *,gint);
+void update_objective_window(gchar *, gchar *, gchar *, gchar *, gchar *,
+			     gchar *, gchar *, gint);
 void populate_combo_list(GtkWidget *);
-
-
