@@ -6,14 +6,14 @@
  * management of the log file, and drawing the pixmaps
  *
  *
- * SNARE GUI Version 2.3 Dated 1 March 2004
+ * SNARE GUI Version 2.4
  *
  ************************************************************/
 
 
 #include "read_config.h"
 
-#define READ_LOG_INTERVAL       1000 //DEFINES THE READ LOG INTERVAL AS 1000 MILLISECS
+#define READ_LOG_INTERVAL       1000	//DEFINES THE READ LOG INTERVAL AS 1000 MILLISECS
 
 #define OPEN_EVENT_FILE			0
 #define READ_EVENT_FILE_FROM_START 	1
@@ -30,10 +30,8 @@ int open_close_event_file(int);
 int declare_new_file(char *);
 void set_network_logging_variable(int);
 
-struct read_events_struct
-  {
-     GtkWidget *main_window;
-     FILE *events_file;
-     int read_type;
-  };
-
+struct read_events_struct {
+	GtkWidget *main_window;
+	FILE *events_file;
+	int read_type;
+};
