@@ -6,15 +6,16 @@
  * window to the snare.conf file
  *
  *
- * SNARE Version 2.3 Dated 1 March 2004
+ * SNARE Version 2.4
  ************************************************************/
 
 
 #define OPEN_FILE       "open_rc,open_rt,open_rtc,open_w,open_wc,open_wt,open_wtc,open_rw,open_rwc,open_rwt,open_rwtc,creat,mkdir,mknod,xmknod,link,symlink,rmdir,unlink,rename,truncate,ftruncate"
 #define OPEN_READ_FILE 	"open_r,readlink"
+#define REMOVE_FILE 	"rmdir,unlink"
 #define LOGON_LOGOFF "login,logout,telnet,rlogin,su,rexecd,passwd,rexd,ftpd,admin_authenticate"
 #define ATTRIBUTES	"chmod,fchmod,chown,fchown,mctl,fcntl,lchown,aclset,faclset"
-#define PROG_EXEC	"exec,execve"
+#define PROG_EXEC	"exec,execve,exit"
 #define USER_IDENT	"setgroups,setpgrp,setuid,setgid,seteuid,setegid,setauid,setreuid,setregid,osetuid,osetpgrp"
 #define ESTABLISH_SOCKET "connect,shutdown,setsockopt"
 
@@ -23,4 +24,4 @@ gint write_header(GtkWidget *, FILE *);
 gint write_log_or_network_parameters(GtkWidget *, FILE *);
 gint write_remote_control_parameters(GtkWidget *, FILE *);
 gint write_objectives(GtkWidget *, FILE *);
-void SetMatch(const char *, char *,int);
+void SetMatch(const char *, char *, int);
